@@ -275,6 +275,13 @@ impl Api {
         self.post::<_, _, (), _>(path, None).await
     }
 
+    pub(crate) async fn report_event<T>(&self, event: &v0::Report<T>) -> ApiResult<()>
+    where
+        T: ser::Serialize,
+    {
+        self.post("/events", event).await
+    }
+
     pub(crate) fn url(&self, path: impl fmt::Display) -> String {
         format!("{}{}", self.base, path)
     }
