@@ -86,7 +86,7 @@ enum Command {
     CreateState {
         #[structopt(help = "State name")]
         name: v0::StateName,
-        #[structopt(long, short, help = "Defalt owning cluster")]
+        #[structopt(long, short, help = "Default owning cluster")]
         owner: Option<v0::ClusterName>,
         #[structopt(long, short, help = "Location definition", alias = "location")]
         locations: Vec<Location>,
@@ -97,6 +97,18 @@ enum Command {
             alias = "cluster"
         )]
         clusters: Vec<v0::ClusterName>,
+        #[structopt(
+            long,
+            help = "Storage class name if different from the state name",
+            visible_alias = "sc"
+        )]
+        storage_class: Option<String>,
+        #[structopt(
+            long,
+            help = "Default filesystem for volumes of this state",
+            visible_alias = "fs"
+        )]
+        fs_type: Option<v0::VolumeFileSystem>,
     },
 
     #[structopt(
@@ -217,9 +229,6 @@ enum Command {
         #[structopt(help = "Skip confirmation", long, short)]
         force: bool,
 
-        #[structopt(help = "Cluster name")]
-        name: v0::ClusterName,
-
         #[structopt(
             help = "Kubeconfig context to use for unregistering cluster",
             long,
@@ -228,6 +237,9 @@ enum Command {
         )]
         context: Option<String>,
 
+        #[structopt(help = "Cluster name")]
+        name: Option<v0::ClusterName>,
+
         #[structopt(
             help = "Non-interactive cluster registration, automatic defaults apply",
             long,
@@ -667,9 +679,13 @@ impl Cli {
                 owner,
                 locations,
                 clusters,
+                storage_class,
+                fs_type,
             } => {
+                let storage_class =
+                    v0::StorageClass::new_if_not_default(&name, storage_class, fs_type);
                 statehub
-                    .create_state(name, owner, locations, clusters)
+                    .create_state(name, owner, locations, clusters, storage_class)
                     .await
             }
             Command::DeleteState { name } => statehub.delete_state(name).await,
@@ -737,11 +753,11 @@ impl Cli {
             }
             Command::UnregisterCluster {
                 force,
-                name,
                 context,
+                name,
                 non_interactive,
             } => {
-                let names = vec![name];
+                let names = name.into_iter().collect();
                 let contexts = context.into_iter().collect();
                 let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
                 let helm = k8s::Helm::skip();
@@ -949,6 +965,7 @@ impl StateHub {
         owner: Option<v0::ClusterName>,
         locations: Vec<Location>,
         clusters: Vec<v0::ClusterName>,
+        storage_class: Option<v0::StorageClass>,
     ) -> anyhow::Result<()> {
         let mut locations = vec![locations];
         for name in &clusters {
@@ -957,7 +974,7 @@ impl StateHub {
         let locations = locations.into_iter().flatten().unique().collect();
         let state = v0::CreateStateDto {
             name,
-            storage_class: None,
+            storage_class,
             owner,
             locations,
             allowed_clusters: None,
