@@ -276,3 +276,26 @@ impl Default for ProvisioningStatus {
         Self::Ready
     }
 }
+
+impl StorageClass {
+    pub(crate) fn new_if_not_default(
+        state: &str,
+        storage_class: Option<String>,
+        fs_type: Option<VolumeFileSystem>,
+    ) -> Option<Self> {
+        if storage_class.is_none() && fs_type.is_none() {
+            return None;
+        }
+
+        let name = storage_class.unwrap_or_else(|| state.to_string());
+        let fs_type = fs_type.unwrap_or_default().to_string();
+
+        let storage_class = Self {
+            name,
+            fs_type,
+            ..Self::default()
+        };
+
+        Some(storage_class)
+    }
+}
