@@ -70,6 +70,12 @@ impl VolumeFileSystem {
     }
 }
 
+impl Default for VolumeFileSystem {
+    fn default() -> Self {
+        Self::Ext4
+    }
+}
+
 impl str::FromStr for VolumeFileSystem {
     type Err = InvalidVolumeFileSystem;
 
